==> pike7.8_7.8.700.orig.tar.gz: Pike-v7.8.700/src/modules/Mysql/acconfig.h <==
/*
|| This file is part of Pike. For copyright information see COPYRIGHT.
|| Pike is distributed under GPL, LGPL and MPL. See the file COPYING
|| for more information.
|| $Id: 9ce5334b8cb3503385a52b9c3ac6b9a8e9d8a717 $
*/

/*
 * Config-file for the Pike mySQL-module.
 *
 * Henrik Grubbstrm 1997-01-30
 */

#ifndef PIKE_MYSQL_CONFIG_H
#define PIKE_MYSQL_CONFIG_H

@TOP@
@BOTTOM@

/* Define if you have mySQL */
#undef HAVE_MYSQL

/* Define if you have SSL support in MySQL */
#undef HAVE_MYSQL_SSL

/* Return type of mysql_fetch_lengths(). Usually unsigned long. */
#undef FETCH_LENGTHS_TYPE

/* Define if your mysql.h defines MYSQL_OPT_RECONNECT */
#undef HAVE_MYSQL_OPT_RECONNECT

/* Define if your mysql.h defines MYSQL_OPT_CONNECT_TIMEOUT */
#undef HAVE_MYSQL_OPT_CONNECT_TIMEOUT

/* Define if your mysql.h defines MYSQL_OPT_COMPRESS */
#undef HAVE_MYSQL_OPT_COMPRESS

/* Define if your mysql.h defines MYSQL_OPT_NAMED_PIPE */
#undef HAVE_MYSQL_OPT_NAMED_PIPE

/* Define if your mysql.h defines MYSQL_INIT_COMMAND */
#undef HAVE_MYSQL_INIT_COMMAND

/* Define if your mysql.h defines MYSQL_READ_DEFAULT_FILE */
#undef HAVE_MYSQL_READ_DEFAULT_FILE

/* Define if your mysql.h defines MYSQL_READ_DEFAULT_GROUP */
#undef HAVE_MYSQL_READ_DEFAULT_GROUP

/* Define if your mysql.h defines MYSQL_SET_CHARSET_DIR */
#undef HAVE_MYSQL_SET_CHARSET_DIR

/* Define if your mysql.h defines MYSQL_SET_CHARSET_NAME */
#undef HAVE_MYSQL_SET_CHARSET_NAME

/* Define if your mysql.h defines MYSQL_OPT_LOCAL_INFILE */
#undef HAVE_MYSQL_OPT_LOCAL_INFILE

/* Define if your mysql.h defines SHUTDOWN_DEFAULT */
#undef HAVE_SHUTDOWN_DEFAULT

/* Define if MYSQL_FIELD has a charsetnr member */
#undef HAVE_MYSQL_FIELD_CHARSETNR

/* Define if MYSQL has a net.vio member */
#undef HAVE_MYSQL_FIELD_NET_VIO

#endif /* PIKE_MYSQL_CONFIG_H */

==> pike8.0_8.0.164.orig.tar.gz: Pike-v8.0.164/src/modules/Mysql/acconfig.h <==
/*
|| This file is part of Pike. For copyright information see COPYRIGHT.
|| Pike is distributed under GPL, LGPL and MPL. See the file COPYING
|| for more information.
*/

/*
 * Config-file for the Pike mySQL-module.
 *
 * Henrik Grubbstrm 1997-01-30
 */

#ifndef PIKE_MYSQL_CONFIG_H
#define PIKE_MYSQL_CONFIG_H

@TOP@
@BOTTOM@

/* Define if you have mySQL */
#undef HAVE_MYSQL

/* Define if you have SSL support in MySQL */
#undef HAVE_MYSQL_SSL

/* Return type of mysql_fetch_lengths(). Usually unsigned long. */
#undef FETCH_LENGTHS_TYPE

/* Define if your mysql.h defines MYSQL_OPT_RECONNECT */
#undef HAVE_MYSQL_OPT_RECONNECT

/* Define if your mysql.h defines MYSQL_OPT_CONNECT_TIMEOUT */
#undef HAVE_MYSQL_OPT_CONNECT_TIMEOUT

/* Define if your mysql.h defines MYSQL_OPT_COMPRESS */
#undef HAVE_MYSQL_OPT_COMPRESS

/* Define if your mysql.h defines MYSQL_OPT_NAMED_PIPE */
#undef HAVE_MYSQL_OPT_NAMED_PIPE

/* Define if your mysql.h defines MYSQL_INIT_COMMAND */
#undef HAVE_MYSQL_INIT_COMMAND

/* Define if your mysql.h defines MYSQL_READ_DEFAULT_FILE */
#undef HAVE_MYSQL_READ_DEFAULT_FILE

/* Define if your mysql.h defines MYSQL_READ_DEFAULT_GROUP */
#undef HAVE_MYSQL_READ_DEFAULT_GROUP

/* Define if your mysql.h defines MYSQL_SET_CHARSET_DIR */
#undef HAVE_MYSQL_SET_CHARSET_DIR

/* Define if your mysql.h defines MYSQL_SET_CHARSET_NAME */
#undef HAVE_MYSQL_SET_CHARSET_NAME

/* Define if your mysql.h defines MYSQL_OPT_LOCAL_INFILE */
#undef HAVE_MYSQL_OPT_LOCAL_INFILE

/* Define if your mysql.h defines SHUTDOWN_DEFAULT */
#undef HAVE_SHUTDOWN_DEFAULT

/* Define if MYSQL_FIELD has a charsetnr member */
#undef HAVE_MYSQL_FIELD_CHARSETNR

/* Define if MYSQL has a net.vio member */
#undef HAVE_MYSQL_FIELD_NET_VIO

/* Define to 1 if you have the <mysql/mysqld_ername.h> header file. */
#undef HAVE_MYSQL_MYSQLD_ERNAME_H

#endif /* PIKE_MYSQL_CONFIG_H */
